summaryrefslogtreecommitdiffstats
path: root/certmanager/storedtransferjob.h
diff options
context:
space:
mode:
Diffstat (limited to 'certmanager/storedtransferjob.h')
-rw-r--r--certmanager/storedtransferjob.h30
1 files changed, 15 insertions, 15 deletions
diff --git a/certmanager/storedtransferjob.h b/certmanager/storedtransferjob.h
index 85b591c6..acc97642 100644
--- a/certmanager/storedtransferjob.h
+++ b/certmanager/storedtransferjob.h
@@ -27,21 +27,21 @@ namespace KIOext {
/**
* StoredTransferJob is a TransferJob (for downloading or uploading data) that
* also stores a QByteArray with the data, making it simpler to use than the
* standard TransferJob.
*
* For KIO::get it puts the data into the member QByteArray, so the user
* of this class can get hold of the whole data at once by calling data()
* when the result signal is emitted.
* You should only use StoredTransferJob to download data if you cannot
* process the data by chunks while it's being downloaded, since storing
* everything in a QByteArray can potentially require a lot of memory.
*
* For KIO::put the user of this class simply provides the bytearray from
* the start, and the job takes care of uploading it.
* You should only use StoredTransferJob to upload data if you cannot
* provide the in chunks while it's being uploaded, since storing
* everything in a QByteArray can potentially require a lot of memory.
*
*/
class StoredTransferJob : public KIO::TransferJob {
@@ -58,32 +58,32 @@ public:
* @param showProgressInfo true to show progress information to the user
*/
StoredTransferJob(const KURL& url, int command,
- const QByteArray &packedArgs,
- const QByteArray &_staticData,
+ const TQByteArray &packedArgs,
+ const TQByteArray &_staticData,
bool showProgressInfo);
/**
* Set data to be uploaded. This is for put jobs.
* Automatically called by KIOext::put(const QByteArray &, ...), do not call this yourself.
*/
- void setData( const QByteArray& arr );
+ void setData( const TQByteArray& arr );
/**
* Get hold of the downloaded data. This is for get jobs.
* You're supposed to call this only from the slot connected to the result() signal.
*/
- QByteArray data() const { return m_data; }
+ TQByteArray data() const { return m_data; }
private slots:
- void slotData( KIO::Job *job, const QByteArray &data );
- void slotDataReq( KIO::Job *job, QByteArray &data );
+ void slotData( KIO::Job *job, const TQByteArray &data );
+ void slotDataReq( KIO::Job *job, TQByteArray &data );
private:
- QByteArray m_data;
+ TQByteArray m_data;
int m_uploadOffset;
};
/**
* Get (a.k.a. read), into a single QByteArray.
* @see StoredTransferJob
*
* @param url the URL of the file
@@ -94,7 +94,7 @@ private:
StoredTransferJob *storedGet( const KURL& url, bool reload=false, bool showProgressInfo = true );
/**
* Put (a.k.a. write) data from a single QByteArray.
* @see StoredTransferJob
*
* @param url Where to write data.
@@ -105,7 +105,7 @@ private:
* @return the job handling the operation.
* @see multi_get()
*/
- StoredTransferJob *put( const QByteArray& arr, const KURL& url, int permissions,
+ StoredTransferJob *put( const TQByteArray& arr, const KURL& url, int permissions,
bool overwrite, bool resume, bool showProgressInfo = true );
} // namespace
@@ -27,21 +27,21 @@ namespace KIOext {
/**
* StoredTransferJob is a TransferJob (for downloading or uploading data) that
- * also stores a QByteArray with the data, making it simpler to use than the
+ * also stores a TQByteArray with the data, making it simpler to use than the
* standard TransferJob.
*
@@ -27,21 +27,21 @@ namespace KIOext {
* standard TransferJob.
*
- * For KIO::get it puts the data into the member QByteArray, so the user
+ * For KIO::get it puts the data into the member TQByteArray, so the user
* of this class can get hold of the whole data at once by calling data()
* when the result signal is emitted.
@@ -27,21 +27,21 @@ namespace KIOext {
* You should only use StoredTransferJob to download data if you cannot
* process the data by chunks while it's being downloaded, since storing
- * everything in a QByteArray can potentially require a lot of memory.
+ * everything in a TQByteArray can potentially require a lot of memory.
*
* For KIO::put the user of this class simply provides the bytearray from
@@ -27,21 +27,21 @@ namespace KIOext {
* You should only use StoredTransferJob to upload data if you cannot
* provide the in chunks while it's being uploaded, since storing
- * everything in a QByteArray can potentially require a lot of memory.
+ * everything in a TQByteArray can potentially require a lot of memory.
*
*/
@@ -58,32 +58,32 @@ public:
/**
* Set data to be uploaded. This is for put jobs.
- * Automatically called by KIOext::put(const QByteArray &, ...), do not call this yourself.
+ * Automatically called by KIOext::put(const TQByteArray &, ...), do not call this yourself.
*/
@@ -58,32 +58,32 @@ public:
};
/**
- * Get (a.k.a. read), into a single QByteArray.
+ * Get (a.k.a. read), into a single TQByteArray.
* @see StoredTransferJob
*
@@ -94,7 +94,7 @@ private:
StoredTransferJob *storedGet( const KURL& url, bool reload=false, bool showProgressInfo = true );
/**
- * Put (a.k.a. write) data from a single QByteArray.
+ * Put (a.k.a. write) data from a single TQByteArray.
* @see StoredTransferJob
*